# Functional API

Convenience functions for quick fitting without creating model objects.

## T1 Functions

::: qmrpy.functional.simulate_t1_vfa

::: qmrpy.functional.fit_t1_vfa

::: qmrpy.functional.fit_t1_vfa_linear

::: qmrpy.functional.simulate_t1_inversion_recovery

::: qmrpy.functional.fit_t1_inversion_recovery

::: qmrpy.functional.fit_t1_despot1_hifi

::: qmrpy.functional.fit_t1_mp2rage

## T2 Functions

::: qmrpy.functional.simulate_t2_mono

::: qmrpy.functional.fit_t2_mono

::: qmrpy.functional.simulate_t2_epg

::: qmrpy.functional.fit_t2_epg

::: qmrpy.functional.fit_t2_multi_component

::: qmrpy.functional.fit_t2_decaes_map

::: qmrpy.functional.decaes_t2map_spectrum

::: qmrpy.functional.fit_t2_emc

## T2* Functions

::: qmrpy.functional.fit_t2star_mono_r2

::: qmrpy.functional.fit_t2star_complex_r2

## B0 Functions

::: qmrpy.functional.fit_b0_dual_echo

::: qmrpy.functional.fit_b0_multi_echo
